Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Package ¶
type Package struct {
ImageName string
Name string `json:"name,omitempty"`
CreateTime time.Time `json:"createTime,omitempty"`
UpdateTime time.Time `json:"updateTime,omitempty"`
}
Package represents a google artifact repository package
func ListPackages ¶
ListPackages lists all the packages in the repository
type Packages ¶
type Packages struct {
Packages []Package `json:"packages,omitempty"`
}
Packages respresents the object returned from the packages endpoint
type Plugin ¶
Plugin respresents Plugin image from the repository
func ListPlugins ¶
ListPlugins gets a list of plugins from the repository
func (*Plugin) Versions ¶
func (p *Plugin) Versions() ([]PluginVersion, error)
Versions gets a list of versions (and related tags) of a plugin
type PluginVersion ¶
type PluginVersion struct {
ImageName string
Digest string
CreateTime time.Time
UpdateTime time.Time
Tags []string
}
PluginVersion respresents Plugin image image version
type Tag ¶
type Tag struct {
Tag string
Name string `json:"name,omitempty"`
Version string `json:"version,omitempty"`
}
Tag represents a google artifact repository image tag
type Tags ¶
type Tags struct {
Tags []Tag `json:"tags,omitempty"`
}
Tags respresents the object returned from the tags endpoint
Click to show internal directories.
Click to hide internal directories.